## v0.2.1 (2022-05-06)

### Fix

- fixed error in report text + formatting

## v0.2.0 (2022-05-06)

### Feat

- #10 added pymc bayesian estimation

### Fix

- fixes error in check for ucm_model arg
- check ucm_arg
- help flake understand unused import
- removed unused assignment

## v0.1.6 (2022-04-30)

### Fix

- fixes #24 using pandas dtype checks
- #18 move to use pandas .any() method for frames/series
- #21 fix for pvalue scaling

## v0.1.5 (2020-03-12)

## v0.1.3 (2017-12-23)

## v0.1.2 (2017-12-20)

## v0.1.1 (2017-11-29)
